@@ -11,7 +11,7 @@ class Hdfs(FileIO):
     
     def __init__(self, storage_type=None):
         super().__init__()
-        self.web_hdfs_url = get_argument('webHdfsUrl')
+        self.web_hdfs_url = get_argument('hdfsUrl')
 
     def upload(self, local_path, remote_path, overwrite=True):
         # Upload model to HDFS
@@ -25,5 +25,6 @@ class Hdfs(FileIO):
 
     def get_modification_time(self, path):
         # Get time when last modified
-        client = InsecureClient(self.web_hdfs_url.replace("hdfs", "http"))
+        url = url = "http:" + self.web_hdfs_url.split(":")[1] + ":50070"
+        client = InsecureClient(url)
         return client.status(hdfs_path=path)['modificationTime']
